@@ -4,14 +4,20 @@
 # If argument is '--no-print', do not print the result.
 
 BEGIN{ $ENV{PERL_RL} = 'Perl' };	# Do not test TR::Gnu !
+use lib './lib';
 use Term::ReadLine;
 
 use Carp;
 $SIG{__WARN__} = sub { warn Carp::longmess(@_) };
 
-my $ev;
-if ($ENV{$ev = 'AUTOMATED_TESTING'} or $ENV{$ev = 'PERL_MM_NONINTERACTIVE'}) {
-  print "1..0 # skip: \$ENV{$ev} is TRUE\n";
+my $non_interactive = 
+    (defined($ENV{PERL_MM_NONINTERACTIVE}))
+    ? $ENV{PERL_MM_NONINTERACTIVE} : 
+     ($ENV{PERL_MM_USE_DEFAULT} || $ENV{AUTOMATED_TESTING});
+if ($non_interactive) {
+    no strict; no warnings;
+    print "1..0 # skip: not interactive; " . 
+    "\$ENV{PERL_MM_NONINTERACTIVE}='$ENV{PERL_MM_NONINTERCTIVE}' \$ENV{AUTOMATED_TESTING}='$ENV{AUTOMATED_TESTING}'\n";
   exit;
 }
 
@@ -30,7 +36,7 @@ if (!@ARGV) {
   $no_print = $ARGV[0] eq '--no-print';
 }
 $prompt = "Enter arithmetic or Perl expression: ";
-if ((my $l = $ENV{PERL_RL_TEST_PROMPT_MINLEN} | 0) > length $prompt) {
+if ((my $l = $ENV{PERL_RL_TEST_PROMPT_MINLEN} || 0) > length $prompt) {
   $prompt =~ s/(?=:)/ ' ' x ($l - length $prompt)/e;
 }
 $OUT = $term->OUT || STDOUT;
